@@ -1,3 +1,8 @@
+# import Qt before pyqtgraph, so version gets set correctly
+import qtpy
+import pyqtgraph as pg
+
+
 try:
     from .__version__ import version as __version__
 except ModuleNotFoundError:
