@@ -1,6 +1,8 @@
 import os
 import re
+
 from dateutil.tz import tzutc, tzlocal
+from qtpy.QtGui import QColor, QBrush
 
 
 # default NDS server
@@ -144,3 +146,15 @@ TICK_DATE_FMT = '%b %d %Y\n%H:%M:%S %Z'
 
 # fill color for labels
 LABEL_FILL = (0, 0, 0, 200)
+
+
+COLOR_MODE = {
+    'light': {
+        'fg': QColor('black'),
+        'bg': QBrush(QColor('white')),
+    },
+    'dark': {
+        'fg': QColor('white'),
+        'bg': QBrush(QColor('black')),
+    },
+}
